@@ -2,10 +2,12 @@ package Crypt::MagicSignatures::Key;
 use strict;
 use warnings;
 use bytes;
+use Carp qw/carp croak/;
 
 use v5.10.1;
 
-use Carp qw/carp croak/;
+our @CARP_NOT;
+
 use Digest::SHA qw/sha256 sha256_hex/;
 use MIME::Base64 qw(decode_base64 encode_base64);
 
@@ -16,7 +18,7 @@ use Math::BigInt try => 'GMP,Pari';
 use Exporter 'import';
 our @EXPORT_OK = qw(b64url_encode b64url_decode);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our $GENERATOR;
 
 # Maximum number of tests for random prime generation
@@ -109,6 +111,7 @@ sub new {
 	$self->$_($param{$_}) if exists $param{$_};
       };
 
+      # Modulus was not defined
       carp 'Key is not well defined' and return unless $self->n;
     }
 
@@ -157,7 +160,7 @@ sub new {
 	  };
 	};
 
-	# Calculate n
+	# Calculate modulus
 	$n = $p * $q;
 
 	# Bitsize is correct based on given size
@@ -215,23 +218,19 @@ sub n {
   # Get value
   unless ($_[0]) {
     return ($self->{n} //= Math::BigInt->bzero);
-  }
-
-  # Set value
-  else {
-    my $n = Math::BigInt->new( shift );
-
-    # n is not a number
-    carp 'n is not a number' and return undef if $n->is_nan;
-
-    # Delete precalculated emLen and size
-    delete $self->{emLen};
-    delete $self->{size};
-
-    return $self->{n} = $n;
   };
 
-  return undef;
+  # Set value
+  my $n = Math::BigInt->new( shift );
+
+  # n is not a number
+  carp 'n is not a number' and return undef if $n->is_nan;
+
+  # Delete precalculated emLen and size
+  delete $self->{emLen};
+  delete $self->{size};
+
+  return $self->{n} = $n;
 };
 
 
@@ -242,19 +241,15 @@ sub e {
   # Get value
   unless ($_[0]) {
     return ($self->{e} //= Math::BigInt->new('65537'));
-  }
-
-  # Set value
-  else {
-    my $e = Math::BigInt->new( shift );
-
-    # e is not a number
-    carp 'e is not a number' and return undef if $e->is_nan;
-
-    return $self->{e} = $e;
   };
 
-  return undef;
+  # Set value
+  my $e = Math::BigInt->new( shift );
+
+  # e is not a number
+  carp 'e is not a number' and return undef if $e->is_nan;
+
+  return $self->{e} = $e;
 };
 
 
@@ -265,19 +260,15 @@ sub d {
   # Get value
   unless ($_[0]) {
     return $self->{d} // undef;
-  }
-
-  # Set value
-  else {
-    my $d = Math::BigInt->new( shift );
-
-    # d is not a number
-    carp 'd is not a number' and return undef if $d->is_nan;
-
-    return $self->{d} = $d;
   };
 
-  return undef;
+  # Set value
+  my $d = Math::BigInt->new( shift );
+
+  # d is not a number
+  carp 'd is not a number' and return undef if $d->is_nan;
+
+  return $self->{d} = $d;
 };
 
 
@@ -494,6 +485,7 @@ sub _emsa_encode {
 # Convert from octet string to bigint
 sub _os2ip {
   # Based on Crypt::RSA::DataFormat
+  # See also Convert::ASN1
 
   my $os = shift;
 
@@ -515,6 +507,7 @@ sub _os2ip {
 # Convert from bigint to octet string
 sub _i2osp {
   # Based on Crypt::RSA::DataFormat
+  # See also Convert::ASN1
 
   my $num = Math::BigInt->new(shift);
 
@@ -522,12 +515,12 @@ sub _i2osp {
   return if $num->length > NUM_LENGTH;
 
   my $l = shift || 0;
+  my $base = Math::BigInt->new(256);
 
   my $result = '';
 
-  if ($l && $num > ( 256 ** $l )) {
-    carp 'i2osp error - Integer is to short';
-    return;
+  if ($l && $num > ( $base ** $l )) {
+    carp 'i2osp error - Integer is to short' and return;
   };
 
   do {
@@ -559,6 +552,7 @@ sub _octet_len {
 sub _bitsize {
   my $int = Math::BigInt->new( shift );
   return 0 unless $int;
+  # Trim leading '0b'
   length( $int->as_bin ) - 2;
 };
 
@@ -568,8 +562,10 @@ sub _b64url_to_hex {
   # Based on
   # https://github.com/sivy/Salmon/blob/master/lib/Salmon/
   #         MagicSignatures/SignatureAlgRsaSha256.pm
-  return Math::BigInt->from_hex(
-    "0x" . unpack( "H*", b64url_decode( shift ) )
+
+  # Decode and convert b64url encoded hex number
+  return Math::BigInt->new(
+    '0x' . unpack( "H*", b64url_decode( shift ) )
   );
 };
 
@@ -579,9 +575,13 @@ sub _hex_to_b64url {
   # https://github.com/sivy/Salmon/blob/master/lib/Salmon/
   #         MagicSignatures/SignatureAlgRsaSha256.pm
 
-  my $num = Math::BigInt->new( shift )->as_hex;
-  $num =~ s/^0x//;
+  # Trim leading '0x'
+  my $num = substr(Math::BigInt->new( shift )->as_hex, 2);
+
+  # Add leading zero padding
   $num = ( ( ( length $num ) % 2 ) > 0 ) ? '0' . $num : $num;
+
+  # Encode number using b64url
   return b64url_encode( pack( "H*", $num ) );
 };
 
